#[non_exhaustive]pub enum ContentError {
Shape,
Encode(EncodeError),
Decode(DecodeError),
}Expand description
A value could not be used as Content.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Shape
The value encoded to a number, a boolean or null. The API takes a
string, an object or an array.
Encode(EncodeError)
The value could not be encoded as JSON at all.
Decode(DecodeError)
A string arrived with escape sequences that do not decode.